# Generated by Django 3.0.2 on 2020-01-29 17:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('black_widow', '0004_auto_20200129_1657'),
    ]

    operations = [
        migrations.AddField(
            model_name='webparsingjobmodel',
            name='cookies',
            field=models.TextField(null=True),
        ),
        migrations.AlterField(
            model_name='webparsingjobmodel',
            name='depth',
            field=models.IntegerField(default=0),
            preserve_default=False,
        ),
    ]
