# Generated by Django 3.0.2 on 2020-01-29 19:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('black_widow', '0005_auto_20200129_1759'),
    ]

    operations = [
        migrations.RenameField(
            model_name='webparsingjobmodel',
            old_name='parsing_tags',
            new_name='_parsing_tags',
        ),
        migrations.RenameField(
            model_name='webparsingjobmodel',
            old_name='parsing_type',
            new_name='_parsing_type',
        ),
    ]
