# Generated by Django 3.0.2 on 2020-01-29 13:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('black_widow', '0002_webparsingjobmodel'),
    ]

    operations = [
        migrations.AddField(
            model_name='webparsingjobmodel',
            name='parsing_tags',
            field=models.CharField(choices=[('ALL_TAGS', 'All Tags'), ('RELEVANT_TAGS', 'Relevant Tags ()'), ('FORM_TAGS', 'Form Tags (form, input, textarea, select, option)')], default='ALL_TAGS', max_length=50),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='webparsingjobmodel',
            name='parsing_type',
            field=models.CharField(choices=[('SINGLE_PAGE', 'Single Page'), ('WEBSITE_CRAWLING', 'Website Crawling')], max_length=50),
        ),
    ]
